summaryrefslogtreecommitdiffstats
path: root/Bugzilla/Install/Filesystem.pm
diff options
context:
space:
mode:
authorwurblzap%gmail.com <>2007-08-18 04:11:49 +0200
committerwurblzap%gmail.com <>2007-08-18 04:11:49 +0200
commitcca9361a1b559716240bf2489891fca0ee201b62 (patch)
treef171771ccc7a5ebc598cd1c14900f93e09141b57 /Bugzilla/Install/Filesystem.pm
parentff5637d1173502aea6527ed917ab963e1b159b6e (diff)
downloadbugzilla-cca9361a1b559716240bf2489891fca0ee201b62.tar.gz
bugzilla-cca9361a1b559716240bf2489891fca0ee201b62.tar.xz
Bug 392573 – Most CSS files are missing from Dusk/, flooding web server error logs.
Patch by Marc Schumann <wurblzap@gmail.com>; r=LpSolit; a=LpSolit
Diffstat (limited to 'Bugzilla/Install/Filesystem.pm')
-rw-r--r--Bugzilla/Install/Filesystem.pm20
1 files changed, 13 insertions, 7 deletions
diff --git a/Bugzilla/Install/Filesystem.pm b/Bugzilla/Install/Filesystem.pm
index 05da26336..8387d0173 100644
--- a/Bugzilla/Install/Filesystem.pm
+++ b/Bugzilla/Install/Filesystem.pm
@@ -34,6 +34,7 @@ use Bugzilla::Util;
use File::Find;
use File::Path;
+use File::Basename;
use IO::File;
use POSIX ();
@@ -201,17 +202,22 @@ sub FILESYSTEM {
);
# Each standard stylesheet has an associated custom stylesheet that
- # we create.
- foreach my $standard (<$skinsdir/standard/*.css>) {
- my $custom = $standard;
- $custom =~ s|\Q$skinsdir\E/standard|$skinsdir/custom|;
- $create_files{$custom} = { perms => $ws_readable, contents => <<EOT
+ # we create. Also, we create placeholders for standard stylesheets
+ # for contrib skins which don't provide them themselves.
+ foreach my $skin_dir ("$skinsdir/custom", <$skinsdir/contrib/*>) {
+ next unless -d $skin_dir;
+ next if basename($skin_dir) =~ /^cvs$/i;
+ foreach (<$skinsdir/standard/*.css>) {
+ my $standard_css_file = basename($_);
+ my $custom_css_file = "$skin_dir/$standard_css_file";
+ $create_files{$custom_css_file} = { perms => $ws_readable, contents => <<EOT
/*
* Custom rules for $standard.
* The rules you put here override rules in that stylesheet.
*/
EOT
- };
+ }
+ }
}
# Because checksetup controls the creation of index.html separately
@@ -201,17 +202,22 @@ sub FILESYSTEM {
/*
- * Custom rules for $standard.
+ * Custom rules for $standard_css_file.
* The rules you put here override rules in that stylesheet.
*/